#!/bin/bash

CURRENT_DISTRO=""
CURRENT_OS=""
function findCurrentOSType()
{
    osType=$(uname)
    case "$osType" in
            "Darwin")
            {
                CURRENT_OS="osx"
            } ;;
            "Linux")
            {
                # If available, use LSB to identify distribution
                if [ -f /etc/lsb-release -o -d /etc/lsb-release.d ]; then
                    DISTRO=$(gawk -F= '/^NAME/{print $2}' /etc/os-release)
                else
                    DISTRO=$(ls -d /etc/[A-Za-z]*[_-][rv]e[lr]* | grep -v "lsb" | cut -d'/' -f3 | cut -d'-' -f1 | cut -d'_' -f1)
                fi
                CURRENT_DISTRO=$(echo $DISTRO | tr 'a-z' 'A-Z')
                CURRENT_OS="linux"
            } ;;
            *)
            {
                CURRENT_OS="na"
                exit
            } ;;
    esac
    echo $CURRENT_OS
}

DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
CDIR=$(pwd)
cd $DIR
os=$(findCurrentOSType)
diamond_local=$(${os}/diamond --version | cut -d' ' -f3)

if [ -z $diamond_local ]; then
  echo "Error: Can't locate DIAMOND"
  exit
fi

echo "Current version of DIAMOND: $diamond_local"
if [ -z "$1" ]; then
  echo "Checking latest release of DIAMOND..."
  diamond_latest=$(curl -s https://github.com/bbuchfink/diamond/releases/latest | sed "s/.*v\(.*\)\".*/\1/")
else
  diamond_latest=$1
fi

if [ $diamond_local = $diamond_latest ]; then
  echo "Local DIAMOND is already latest release!"
else
  echo "Downloading DIAMOND ${diamond_latest}..."
  wget --quiet https://github.com/bbuchfink/diamond/archive/v${diamond_latest}.tar.gz
  tar xzf v${diamond_latest}.tar.gz
  echo "Renaming current DIAMOND binary to diamond-${diamond_local}_bak"
  mv ${os}/diamond ${os}/diamond-${diamond_local}_bak
  echo "Building DIAMOND ${diamond_latest}..."
  cd diamond-${diamond_latest}
  ./build_simple.sh
  mv diamond ../${os}/
  cd ..
  echo "Cleaning up..."
  rm -rf diamond-$diamond_latest
  rm -f v${diamond_latest}.tar.gz
  echo "Renaming current database to GS-${diamond_local}_bak"
  mv ../database/GS.dmnd ../database/GS-${diamond_local}_bak.dmnd
  echo "Updating database..."
  ./${os}/diamond makedb --in ../database/gold_standard.fasta -d ../database/GS
  echo "DIAMOND binary and database updated: $diamond_local -> $diamond_latest"
fi

cd $CDIR
